[Tickets #10493] Nag instaled with DIMP - PHP Catchable fatal error
bugs at horde.org
bugs at horde.org
Thu Sep 8 15:46:49 UTC 2011
DO NOT REPLY TO THIS MESSAGE. THIS EMAIL ADDRESS IS NOT MONITORED.
Ticket URL: http://bugs.horde.org/ticket/10493
------------------------------------------------------------------------------
Ticket | 10493
Created By | joao.machado at co.sapo.pt
Summary | Nag instaled with DIMP - PHP Catchable fatal error
Queue | Nag
Version | Git master
Type | Bug
State | Unconfirmed
Priority | 3. High
Milestone |
Patch |
Owners |
------------------------------------------------------------------------------
joao.machado at co.sapo.pt (2011-09-08 15:46) wrote:
I have imp with nag activated. Since this commits:
f209a04866f6ac02341f83b970655bec5962392b 2011-09-01 10:59 Gunnar
Wrobel Remove unncessary interface.
a9a725c21f1c70002dd2f2b4f1f688818bd6f52b 2011-09-01 05:42 Gunnar
Wrobel Add a new handler for task lists.
I have this fatal error:
PHP Catchable fatal error: Argument 1 passed to
Nag_Tasklists_Default::__construct() must be an instance
of Horde_Share_Base, instance of Horde_Core_Share_Driver given,
called in
/disc2/gits/jpdev.webmail.labs.sapo.pt/webmail/nag/lib/Factory/Tasklists.php
on line 65 and
defined in
/disc2/gits/jpdev.webmail.labs.sapo.pt/webmail/nag/lib/Tasklists/Default.php
on line 28
I have made this fix, but dont know if is the correct solution.
diff --git a/nag/lib/Tasklists/Base.php b/nag/lib/Tasklists/Base.php
index 5af7ce2..70309f9 100644
--- a/nag/lib/Tasklists/Base.php
+++ b/nag/lib/Tasklists/Base.php
@@ -34,11 +34,11 @@ abstract class Nag_Tasklists_Base
/**
* Constructor.
*
* @param Horde_Share_Base $shares The share backend.
* @param string $user The current user.
* @param array $params Additional parameters.
*/
- public function __construct(Horde_Share_Base $shares, $user, $params)
+ public function __construct(Horde_Core_Share_Driver $shares,
$user, $params)
{
$this->shares = $shares;
@@ -34,11 +34,11 @@ abstract class Nag_Tasklists_Base
* Constructor.
*
- * @param Horde_Share_Base $shares The share backend.
- * @param string $user The current user.
- * @param array $params Additional parameters.
+ * @param Horde_Core_Share_Driver $shares The share backend.
+ * @param string $user The current user.
+ * @param array $params Additional parameters.
*/
$this->user = $user;
diff --git a/nag/lib/Tasklists/Default.php b/nag/lib/Tasklists/Default.php
index b5e711d..7359960 100644
--- a/nag/lib/Tasklists/Default.php
+++ b/nag/lib/Tasklists/Default.php
@@ -21,11 +21,11 @@ extends Nag_Tasklists_Base
/**
* Constructor.
*
* @param Horde_Share_Base $shares The share backend.
* @param string $user The current user.
* @param array $params Additional parameters.
*/
- public function __construct(Horde_Share_Base $shares, $user, $params)
+ public function __construct(Horde_Core_Share_Driver $shares,
$user, $params)
{
if (!isset($params['identity'])) {
@@ -21,11 +21,11 @@ extends Nag_Tasklists_Base
* Constructor.
*
- * @param Horde_Share_Base $shares The share backend.
- * @param string $user The current user.
- * @param array $params Additional parameters.
+ * @param Horde_Core_Share_Driver $shares The share backend.
+ * @param string $user The current user.
+ * @param array $params Additional parameters.
*/
throw new Nag_Exception('This tasklist handler needs an
"identity" parameter!');
Thanks
More information about the bugs
mailing list